Learn R Programming

dispeRse (version 1.1)

euro_dates: Coordinates and earliest dates (med cal BP) for European Neolithic sites. Dataset adapted from the supplementary information in Pinhasi et al. 2005 (https://doi.org/10.1371/journal.pbio.0030410).

Description

Coordinates and earliest dates (med cal BP) for European Neolithic sites. Dataset adapted from the supplementary information in Pinhasi et al. 2005 (https://doi.org/10.1371/journal.pbio.0030410).

Usage

euro_dates

Arguments

Format

A SpatialPointsDataFrame object.