Learn R Programming

dispeRse (version 1.1)

ppnb: Coordinates and earliest dates (med cal BP) for Late Pre-Pottery Neolithic B sites in the Near East. Dataset adapted from the supplementary information in Pinhasi et al. 2005 (https://doi.org/10.1371/journal.pbio.0030410).

Description

Coordinates and earliest dates (med cal BP) for Late Pre-Pottery Neolithic B sites in the Near East. Dataset adapted from the supplementary information in Pinhasi et al. 2005 (https://doi.org/10.1371/journal.pbio.0030410).

Usage

ppnb

Arguments

Format

A DataFrame object.