Convert from geographic coordinates in a given projection system to the relative position in rows and columns of a grid.
.to_grid(coords, grid)A DataFrame with the converted coordinates.
A SpatialPointsDataFrame. Must contain a column dates with the start date of the dispersal from each point.
A Raster*. The coordinates will be converted to this grid.